@@ -16,9 +16,10 @@ def doctest_configuration():
 
     """
 
-def test_suite():
+def test_suite(*args):
     return doctest.DocTestSuite(optionflags=(doctest.NORMALIZE_WHITESPACE|
                                              doctest.ELLIPSIS|
                                              doctest.REPORT_ONLY_FIRST_FAILURE|
                                              doctest.REPORT_NDIFF
                                              ))
+load_tests = test_suite
